import { __awaiter } from '../../_virtual/_tslib.js';
import { BaseAPI, RequiredError, JSONApiResponse } from '../runtime.js';
import '../models/AccessOutcomeEnum.js';
import '../models/ExchangeKeyEnum.js';
import { AnalyticsEngagementResponseFromJSON } from '../models/AnalyticsEngagementResponse.js';
import { AnalyticsOverviewResponseFromJSON } from '../models/AnalyticsOverviewResponse.js';
import { AnalyticsToplineResponseFromJSON } from '../models/AnalyticsToplineResponse.js';
import { AnalyticsVisitResponseFromJSON } from '../models/AnalyticsVisitResponse.js';
import { AnalyticsWalletsResponseFromJSON } from '../models/AnalyticsWalletsResponse.js';
import '../models/AttestationConveyancePreference.js';
import '../models/AuthModeEnum.js';
import '../models/AuthStorageEnum.js';
import '../models/AuthenticatorAttachment.js';
import '../models/ResidentKeyRequirement.js';
import '../models/UserVerificationRequirement.js';
import '../models/AuthenticatorTransportProtocol.js';
import '../models/JwtVerifiedCredentialFormatEnum.js';
import '../models/ProviderEnum.js';
import '../models/WalletAddressType.js';
import '../models/EcdsaValidatorOptions.js';
import '../models/EmbeddedWalletVersionEnum.js';
import '../models/HardwareWalletEnum.js';
import '../models/PasswordSourceTypeEnum.js';
import '../models/ProviderEntryPointVersionEnum.js';
import '../models/ProviderKernelVersionEnum.js';
import '../models/ThresholdSignatureScheme.js';
import '../models/WalletProviderEnum.js';
import '../models/MfaBackupCodeAcknowledgement.js';
import '../models/CustomFieldType.js';
import '../models/KycFieldType.js';
import '../models/BillingSubscriptionPlanTypeEnum.js';
import '../models/UnprocessableEntityErrorCode.js';
import '../models/ChainEnum.js';
import '../models/ChainalysisCheckResultEnum.js';
import '../models/MFADeviceType.js';
import '../models/EmbeddedWalletChainEnum.js';
import '../models/EmbeddedWalletProviderEnum.js';
import '../models/UserIdentifierTypeEnum.js';
import '../models/WaasChainEnum.js';
import '../models/CurrencyType.js';
import '../models/CustomHostnameStatusEnum.js';
import '../models/CustomHostnameUsageEnum.js';
import '../models/CustomHostnameVerificationType.js';
import '../models/DnsRecordType.js';
import '../models/TimeUnitEnum.js';
import '../models/EmbeddedWalletAuthType.js';
import '../models/EmbeddedWalletSecurityMethod.js';
import '../models/EnvironmentEnum.js';
import '../models/Network.js';
import '../models/ExternalWalletFundingTokenRule.js';
import '../models/OnrampProviders.js';
import '../models/SignInProviderEnum.js';
import '../models/SocialSignInProviderEnum.js';
import '../models/WaasBackupOptionsEnum.js';
import '../models/SdkViewSectionAlignment.js';
import '../models/SdkViewSectionType.js';
import '../models/SdkViewType.js';
import '../models/ZerodevBundlerProvider.js';
import '../models/ExportFormatEnum.js';
import '../models/ExportModelEnum.js';
import '../models/ExportStatusEnum.js';
import '../models/ExternalWalletFundingDefaultChain.js';
import '../models/GateRuleType.js';
import '../models/GlobalWalletAccessControlTypeEnum.js';
import '../models/HealthcheckStatus.js';
import '../models/InviteStatusEnum.js';
import '../models/RoleEnum.js';
import '../models/PublicKeyCredentialType.js';
import '../models/NextViewEnum.js';
import '../models/OauthResultStatus.js';
import '../models/WhenToImplementEnum.js';
import '../models/PublishEventsEvents.js';
import '../models/SubscriptionAdvancedScopeEnum.js';
import '../models/SubscriptionFreeScopeEnum.js';
import '../models/UserFieldsCheckEnum.js';
import '../models/UserFilterableFieldsEnum.js';
import '../models/VisitorFilterableFieldsEnum.js';

/* tslint:disable */
/**
 *
 */
class AnalyticsApi extends BaseAPI {
    /**
     * Get analytics engagement data
     */
    getAnalyticsEngagementRaw(requestParameters, initOverrides) {
        return __awaiter(this, void 0, void 0, function* () {
            if (requestParameters.environmentId === null || requestParameters.environmentId === undefined) {
                throw new RequiredError('environmentId', 'Required parameter requestParameters.environmentId was null or undefined when calling getAnalyticsEngagement.');
            }
            if (requestParameters.start === null || requestParameters.start === undefined) {
                throw new RequiredError('start', 'Required parameter requestParameters.start was null or undefined when calling getAnalyticsEngagement.');
            }
            if (requestParameters.end === null || requestParameters.end === undefined) {
                throw new RequiredError('end', 'Required parameter requestParameters.end was null or undefined when calling getAnalyticsEngagement.');
            }
            const queryParameters = {};
            if (requestParameters.start !== undefined) {
                queryParameters['start'] = requestParameters.start;
            }
            if (requestParameters.end !== undefined) {
                queryParameters['end'] = requestParameters.end;
            }
            const headerParameters = {};
            if (this.configuration && this.configuration.accessToken) {
                const token = this.configuration.accessToken;
                const tokenString = yield token("bearerAuth", []);
                if (tokenString) {
                    headerParameters["Authorization"] = `Bearer ${tokenString}`;
                }
            }
            const response = yield this.request({
                path: `/environments/{environmentId}/analytics/engagement`.replace(`{${"environmentId"}}`, encodeURIComponent(String(requestParameters.environmentId))),
                method: 'GET',
                headers: headerParameters,
                query: queryParameters,
            }, initOverrides);
            return new JSONApiResponse(response, (jsonValue) => AnalyticsEngagementResponseFromJSON(jsonValue));
        });
    }
    /**
     * Get analytics engagement data
     */
    getAnalyticsEngagement(requestParameters, initOverrides) {
        return __awaiter(this, void 0, void 0, function* () {
            const response = yield this.getAnalyticsEngagementRaw(requestParameters, initOverrides);
            return yield response.value();
        });
    }
    /**
     * Get analytics overview data
     */
    getAnalyticsOverviewRaw(requestParameters, initOverrides) {
        return __awaiter(this, void 0, void 0, function* () {
            if (requestParameters.environmentId === null || requestParameters.environmentId === undefined) {
                throw new RequiredError('environmentId', 'Required parameter requestParameters.environmentId was null or undefined when calling getAnalyticsOverview.');
            }
            if (requestParameters.start === null || requestParameters.start === undefined) {
                throw new RequiredError('start', 'Required parameter requestParameters.start was null or undefined when calling getAnalyticsOverview.');
            }
            if (requestParameters.end === null || requestParameters.end === undefined) {
                throw new RequiredError('end', 'Required parameter requestParameters.end was null or undefined when calling getAnalyticsOverview.');
            }
            if (requestParameters.granularity === null || requestParameters.granularity === undefined) {
                throw new RequiredError('granularity', 'Required parameter requestParameters.granularity was null or undefined when calling getAnalyticsOverview.');
            }
            const queryParameters = {};
            if (requestParameters.start !== undefined) {
                queryParameters['start'] = requestParameters.start;
            }
            if (requestParameters.end !== undefined) {
                queryParameters['end'] = requestParameters.end;
            }
            if (requestParameters.granularity !== undefined) {
                queryParameters['granularity'] = requestParameters.granularity;
            }
            const headerParameters = {};
            if (this.configuration && this.configuration.accessToken) {
                const token = this.configuration.accessToken;
                const tokenString = yield token("bearerAuth", []);
                if (tokenString) {
                    headerParameters["Authorization"] = `Bearer ${tokenString}`;
                }
            }
            const response = yield this.request({
                path: `/environments/{environmentId}/analytics/overview`.replace(`{${"environmentId"}}`, encodeURIComponent(String(requestParameters.environmentId))),
                method: 'GET',
                headers: headerParameters,
                query: queryParameters,
            }, initOverrides);
            return new JSONApiResponse(response, (jsonValue) => AnalyticsOverviewResponseFromJSON(jsonValue));
        });
    }
    /**
     * Get analytics overview data
     */
    getAnalyticsOverview(requestParameters, initOverrides) {
        return __awaiter(this, void 0, void 0, function* () {
            const response = yield this.getAnalyticsOverviewRaw(requestParameters, initOverrides);
            return yield response.value();
        });
    }
    /**
     * Get analytics topline data
     */
    getAnalyticsToplineRaw(requestParameters, initOverrides) {
        return __awaiter(this, void 0, void 0, function* () {
            if (requestParameters.environmentId === null || requestParameters.environmentId === undefined) {
                throw new RequiredError('environmentId', 'Required parameter requestParameters.environmentId was null or undefined when calling getAnalyticsTopline.');
            }
            if (requestParameters.start === null || requestParameters.start === undefined) {
                throw new RequiredError('start', 'Required parameter requestParameters.start was null or undefined when calling getAnalyticsTopline.');
            }
            if (requestParameters.end === null || requestParameters.end === undefined) {
                throw new RequiredError('end', 'Required parameter requestParameters.end was null or undefined when calling getAnalyticsTopline.');
            }
            const queryParameters = {};
            if (requestParameters.start !== undefined) {
                queryParameters['start'] = requestParameters.start;
            }
            if (requestParameters.end !== undefined) {
                queryParameters['end'] = requestParameters.end;
            }
            const headerParameters = {};
            if (this.configuration && this.configuration.accessToken) {
                const token = this.configuration.accessToken;
                const tokenString = yield token("bearerAuth", []);
                if (tokenString) {
                    headerParameters["Authorization"] = `Bearer ${tokenString}`;
                }
            }
            const response = yield this.request({
                path: `/environments/{environmentId}/analytics/topline`.replace(`{${"environmentId"}}`, encodeURIComponent(String(requestParameters.environmentId))),
                method: 'GET',
                headers: headerParameters,
                query: queryParameters,
            }, initOverrides);
            return new JSONApiResponse(response, (jsonValue) => AnalyticsToplineResponseFromJSON(jsonValue));
        });
    }
    /**
     * Get analytics topline data
     */
    getAnalyticsTopline(requestParameters, initOverrides) {
        return __awaiter(this, void 0, void 0, function* () {
            const response = yield this.getAnalyticsToplineRaw(requestParameters, initOverrides);
            return yield response.value();
        });
    }
    /**
     * Get analytics wallets breakdown data
     */
    getAnalyticsWalletsRaw(requestParameters, initOverrides) {
        return __awaiter(this, void 0, void 0, function* () {
            if (requestParameters.environmentId === null || requestParameters.environmentId === undefined) {
                throw new RequiredError('environmentId', 'Required parameter requestParameters.environmentId was null or undefined when calling getAnalyticsWallets.');
            }
            if (requestParameters.start === null || requestParameters.start === undefined) {
                throw new RequiredError('start', 'Required parameter requestParameters.start was null or undefined when calling getAnalyticsWallets.');
            }
            if (requestParameters.end === null || requestParameters.end === undefined) {
                throw new RequiredError('end', 'Required parameter requestParameters.end was null or undefined when calling getAnalyticsWallets.');
            }
            if (requestParameters.chain === null || requestParameters.chain === undefined) {
                throw new RequiredError('chain', 'Required parameter requestParameters.chain was null or undefined when calling getAnalyticsWallets.');
            }
            const queryParameters = {};
            if (requestParameters.start !== undefined) {
                queryParameters['start'] = requestParameters.start;
            }
            if (requestParameters.end !== undefined) {
                queryParameters['end'] = requestParameters.end;
            }
            if (requestParameters.chain !== undefined) {
                queryParameters['chain'] = requestParameters.chain;
            }
            const headerParameters = {};
            if (this.configuration && this.configuration.accessToken) {
                const token = this.configuration.accessToken;
                const tokenString = yield token("bearerAuth", []);
                if (tokenString) {
                    headerParameters["Authorization"] = `Bearer ${tokenString}`;
                }
            }
            const response = yield this.request({
                path: `/environments/{environmentId}/analytics/walletsBreakdown`.replace(`{${"environmentId"}}`, encodeURIComponent(String(requestParameters.environmentId))),
                method: 'GET',
                headers: headerParameters,
                query: queryParameters,
            }, initOverrides);
            return new JSONApiResponse(response, (jsonValue) => AnalyticsWalletsResponseFromJSON(jsonValue));
        });
    }
    /**
     * Get analytics wallets breakdown data
     */
    getAnalyticsWallets(requestParameters, initOverrides) {
        return __awaiter(this, void 0, void 0, function* () {
            const response = yield this.getAnalyticsWalletsRaw(requestParameters, initOverrides);
            return yield response.value();
        });
    }
    /**
     * Fetch visit analytics
     */
    getVisitAnalyticsRaw(requestParameters, initOverrides) {
        return __awaiter(this, void 0, void 0, function* () {
            if (requestParameters.environmentId === null || requestParameters.environmentId === undefined) {
                throw new RequiredError('environmentId', 'Required parameter requestParameters.environmentId was null or undefined when calling getVisitAnalytics.');
            }
            const queryParameters = {};
            if (requestParameters.startDate !== undefined) {
                queryParameters['startDate'] = requestParameters.startDate;
            }
            if (requestParameters.endDate !== undefined) {
                queryParameters['endDate'] = requestParameters.endDate;
            }
            const headerParameters = {};
            if (this.configuration && this.configuration.accessToken) {
                const token = this.configuration.accessToken;
                const tokenString = yield token("bearerAuth", []);
                if (tokenString) {
                    headerParameters["Authorization"] = `Bearer ${tokenString}`;
                }
            }
            const response = yield this.request({
                path: `/environments/{environmentId}/analytics/visits`.replace(`{${"environmentId"}}`, encodeURIComponent(String(requestParameters.environmentId))),
                method: 'GET',
                headers: headerParameters,
                query: queryParameters,
            }, initOverrides);
            return new JSONApiResponse(response, (jsonValue) => AnalyticsVisitResponseFromJSON(jsonValue));
        });
    }
    /**
     * Fetch visit analytics
     */
    getVisitAnalytics(requestParameters, initOverrides) {
        return __awaiter(this, void 0, void 0, function* () {
            const response = yield this.getVisitAnalyticsRaw(requestParameters, initOverrides);
            return yield response.value();
        });
    }
    /**
     * Fetch wallets breakdown
     */
    getWalletsBreakdownRaw(requestParameters, initOverrides) {
        return __awaiter(this, void 0, void 0, function* () {
            if (requestParameters.environmentId === null || requestParameters.environmentId === undefined) {
                throw new RequiredError('environmentId', 'Required parameter requestParameters.environmentId was null or undefined when calling getWalletsBreakdown.');
            }
            const queryParameters = {};
            if (requestParameters.startDate !== undefined) {
                queryParameters['startDate'] = requestParameters.startDate;
            }
            if (requestParameters.endDate !== undefined) {
                queryParameters['endDate'] = requestParameters.endDate;
            }
            const headerParameters = {};
            if (this.configuration && this.configuration.accessToken) {
                const token = this.configuration.accessToken;
                const tokenString = yield token("bearerAuth", []);
                if (tokenString) {
                    headerParameters["Authorization"] = `Bearer ${tokenString}`;
                }
            }
            const response = yield this.request({
                path: `/environments/{environmentId}/analytics/wallets`.replace(`{${"environmentId"}}`, encodeURIComponent(String(requestParameters.environmentId))),
                method: 'GET',
                headers: headerParameters,
                query: queryParameters,
            }, initOverrides);
            return new JSONApiResponse(response);
        });
    }
    /**
     * Fetch wallets breakdown
     */
    getWalletsBreakdown(requestParameters, initOverrides) {
        return __awaiter(this, void 0, void 0, function* () {
            const response = yield this.getWalletsBreakdownRaw(requestParameters, initOverrides);
            return yield response.value();
        });
    }
}
/**
    * @export
    * @enum {string}
    */
var GetAnalyticsOverviewGranularityEnum;
(function (GetAnalyticsOverviewGranularityEnum) {
    GetAnalyticsOverviewGranularityEnum["Day"] = "day";
    GetAnalyticsOverviewGranularityEnum["Week"] = "week";
    GetAnalyticsOverviewGranularityEnum["Month"] = "month";
})(GetAnalyticsOverviewGranularityEnum || (GetAnalyticsOverviewGranularityEnum = {}));

export { AnalyticsApi, GetAnalyticsOverviewGranularityEnum };
