import { __awaiter } from '../../_virtual/_tslib.js';
import { BaseAPI, RequiredError, JSONApiResponse, VoidApiResponse } from '../runtime.js';
import '../models/AccessOutcomeEnum.js';
import '../models/ExchangeKeyEnum.js';
import '../models/AttestationConveyancePreference.js';
import '../models/AuthModeEnum.js';
import '../models/AuthStorageEnum.js';
import '../models/AuthenticatorAttachment.js';
import '../models/ResidentKeyRequirement.js';
import '../models/UserVerificationRequirement.js';
import '../models/AuthenticatorTransportProtocol.js';
import '../models/JwtVerifiedCredentialFormatEnum.js';
import '../models/ProviderEnum.js';
import '../models/WalletAddressType.js';
import '../models/EcdsaValidatorOptions.js';
import '../models/EmbeddedWalletVersionEnum.js';
import '../models/HardwareWalletEnum.js';
import '../models/PasswordSourceTypeEnum.js';
import '../models/ProviderEntryPointVersionEnum.js';
import '../models/ProviderKernelVersionEnum.js';
import '../models/ThresholdSignatureScheme.js';
import '../models/WalletProviderEnum.js';
import '../models/MfaBackupCodeAcknowledgement.js';
import '../models/CustomFieldType.js';
import '../models/KycFieldType.js';
import '../models/BillingSubscriptionPlanTypeEnum.js';
import '../models/UnprocessableEntityErrorCode.js';
import '../models/ChainEnum.js';
import '../models/ChainalysisCheckResultEnum.js';
import '../models/MFADeviceType.js';
import '../models/EmbeddedWalletChainEnum.js';
import '../models/EmbeddedWalletProviderEnum.js';
import '../models/UserIdentifierTypeEnum.js';
import '../models/WaasChainEnum.js';
import '../models/CurrencyType.js';
import '../models/CustomHostnameStatusEnum.js';
import '../models/CustomHostnameUsageEnum.js';
import '../models/CustomHostnameVerificationType.js';
import '../models/DnsRecordType.js';
import '../models/TimeUnitEnum.js';
import '../models/EmbeddedWalletAuthType.js';
import '../models/EmbeddedWalletSecurityMethod.js';
import '../models/EnvironmentEnum.js';
import '../models/Network.js';
import '../models/ExternalWalletFundingTokenRule.js';
import '../models/OnrampProviders.js';
import '../models/SignInProviderEnum.js';
import '../models/SocialSignInProviderEnum.js';
import '../models/WaasBackupOptionsEnum.js';
import '../models/SdkViewSectionAlignment.js';
import '../models/SdkViewSectionType.js';
import '../models/SdkViewType.js';
import '../models/ZerodevBundlerProvider.js';
import '../models/ExportFormatEnum.js';
import '../models/ExportModelEnum.js';
import '../models/ExportStatusEnum.js';
import '../models/ExternalWalletFundingDefaultChain.js';
import '../models/GateRuleType.js';
import { GlobalWalletAccessControlDomainCreateRequestToJSON } from '../models/GlobalWalletAccessControlDomainCreateRequest.js';
import { GlobalWalletAccessControlDomainResponseFromJSON } from '../models/GlobalWalletAccessControlDomainResponse.js';
import { GlobalWalletAccessControlResponseFromJSON } from '../models/GlobalWalletAccessControlResponse.js';
import '../models/GlobalWalletAccessControlTypeEnum.js';
import { GlobalWalletAccessControlUpdateRequestToJSON } from '../models/GlobalWalletAccessControlUpdateRequest.js';
import '../models/HealthcheckStatus.js';
import '../models/InviteStatusEnum.js';
import '../models/RoleEnum.js';
import '../models/PublicKeyCredentialType.js';
import '../models/NextViewEnum.js';
import '../models/OauthResultStatus.js';
import '../models/WhenToImplementEnum.js';
import '../models/PublishEventsEvents.js';
import '../models/SubscriptionAdvancedScopeEnum.js';
import '../models/SubscriptionFreeScopeEnum.js';
import '../models/UserFieldsCheckEnum.js';
import '../models/UserFilterableFieldsEnum.js';
import '../models/VisitorFilterableFieldsEnum.js';

/* tslint:disable */
/**
 *
 */
class GlobalWalletAccessControlApi extends BaseAPI {
    /**
     * Adds a domain to be allowed or blocked for global wallet access for this project environment
     */
    addGlobalWalletAccessControlDomainRaw(requestParameters, initOverrides) {
        return __awaiter(this, void 0, void 0, function* () {
            if (requestParameters.environmentId === null || requestParameters.environmentId === undefined) {
                throw new RequiredError('environmentId', 'Required parameter requestParameters.environmentId was null or undefined when calling addGlobalWalletAccessControlDomain.');
            }
            if (requestParameters.globalWalletAccessControlDomainCreateRequest === null || requestParameters.globalWalletAccessControlDomainCreateRequest === undefined) {
                throw new RequiredError('globalWalletAccessControlDomainCreateRequest', 'Required parameter requestParameters.globalWalletAccessControlDomainCreateRequest was null or undefined when calling addGlobalWalletAccessControlDomain.');
            }
            const queryParameters = {};
            const headerParameters = {};
            headerParameters['Content-Type'] = 'application/json';
            if (this.configuration && this.configuration.accessToken) {
                const token = this.configuration.accessToken;
                const tokenString = yield token("bearerAuth", []);
                if (tokenString) {
                    headerParameters["Authorization"] = `Bearer ${tokenString}`;
                }
            }
            const response = yield this.request({
                path: `/environments/{environmentId}/globalWallet/accessControl/domains`.replace(`{${"environmentId"}}`, encodeURIComponent(String(requestParameters.environmentId))),
                method: 'POST',
                headers: headerParameters,
                query: queryParameters,
                body: GlobalWalletAccessControlDomainCreateRequestToJSON(requestParameters.globalWalletAccessControlDomainCreateRequest),
            }, initOverrides);
            return new JSONApiResponse(response, (jsonValue) => GlobalWalletAccessControlDomainResponseFromJSON(jsonValue));
        });
    }
    /**
     * Adds a domain to be allowed or blocked for global wallet access for this project environment
     */
    addGlobalWalletAccessControlDomain(requestParameters, initOverrides) {
        return __awaiter(this, void 0, void 0, function* () {
            const response = yield this.addGlobalWalletAccessControlDomainRaw(requestParameters, initOverrides);
            return yield response.value();
        });
    }
    /**
     * Creates a global wallet access control for this project environment
     */
    createGlobalWalletAccessControlRaw(requestParameters, initOverrides) {
        return __awaiter(this, void 0, void 0, function* () {
            if (requestParameters.environmentId === null || requestParameters.environmentId === undefined) {
                throw new RequiredError('environmentId', 'Required parameter requestParameters.environmentId was null or undefined when calling createGlobalWalletAccessControl.');
            }
            if (requestParameters.globalWalletAccessControlUpdateRequest === null || requestParameters.globalWalletAccessControlUpdateRequest === undefined) {
                throw new RequiredError('globalWalletAccessControlUpdateRequest', 'Required parameter requestParameters.globalWalletAccessControlUpdateRequest was null or undefined when calling createGlobalWalletAccessControl.');
            }
            const queryParameters = {};
            const headerParameters = {};
            headerParameters['Content-Type'] = 'application/json';
            if (this.configuration && this.configuration.accessToken) {
                const token = this.configuration.accessToken;
                const tokenString = yield token("bearerAuth", []);
                if (tokenString) {
                    headerParameters["Authorization"] = `Bearer ${tokenString}`;
                }
            }
            const response = yield this.request({
                path: `/environments/{environmentId}/globalWallet/accessControl`.replace(`{${"environmentId"}}`, encodeURIComponent(String(requestParameters.environmentId))),
                method: 'POST',
                headers: headerParameters,
                query: queryParameters,
                body: GlobalWalletAccessControlUpdateRequestToJSON(requestParameters.globalWalletAccessControlUpdateRequest),
            }, initOverrides);
            return new JSONApiResponse(response, (jsonValue) => GlobalWalletAccessControlResponseFromJSON(jsonValue));
        });
    }
    /**
     * Creates a global wallet access control for this project environment
     */
    createGlobalWalletAccessControl(requestParameters, initOverrides) {
        return __awaiter(this, void 0, void 0, function* () {
            const response = yield this.createGlobalWalletAccessControlRaw(requestParameters, initOverrides);
            return yield response.value();
        });
    }
    /**
     * Delete a global wallet access control domain by id
     */
    deleteGlobalWalletAccessControlDomainByIdRaw(requestParameters, initOverrides) {
        return __awaiter(this, void 0, void 0, function* () {
            if (requestParameters.environmentId === null || requestParameters.environmentId === undefined) {
                throw new RequiredError('environmentId', 'Required parameter requestParameters.environmentId was null or undefined when calling deleteGlobalWalletAccessControlDomainById.');
            }
            if (requestParameters.globalWalletAccessControlDomainId === null || requestParameters.globalWalletAccessControlDomainId === undefined) {
                throw new RequiredError('globalWalletAccessControlDomainId', 'Required parameter requestParameters.globalWalletAccessControlDomainId was null or undefined when calling deleteGlobalWalletAccessControlDomainById.');
            }
            const queryParameters = {};
            const headerParameters = {};
            if (this.configuration && this.configuration.accessToken) {
                const token = this.configuration.accessToken;
                const tokenString = yield token("bearerAuth", []);
                if (tokenString) {
                    headerParameters["Authorization"] = `Bearer ${tokenString}`;
                }
            }
            const response = yield this.request({
                path: `/environments/{environmentId}/globalWallet/accessControl/domains/{globalWalletAccessControlDomainId}`.replace(`{${"environmentId"}}`, encodeURIComponent(String(requestParameters.environmentId))).replace(`{${"globalWalletAccessControlDomainId"}}`, encodeURIComponent(String(requestParameters.globalWalletAccessControlDomainId))),
                method: 'DELETE',
                headers: headerParameters,
                query: queryParameters,
            }, initOverrides);
            return new VoidApiResponse(response);
        });
    }
    /**
     * Delete a global wallet access control domain by id
     */
    deleteGlobalWalletAccessControlDomainById(requestParameters, initOverrides) {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.deleteGlobalWalletAccessControlDomainByIdRaw(requestParameters, initOverrides);
        });
    }
    /**
     * Disabled global wallet access control for this environment
     */
    disableGlobalWalletAccessControlRaw(requestParameters, initOverrides) {
        return __awaiter(this, void 0, void 0, function* () {
            if (requestParameters.environmentId === null || requestParameters.environmentId === undefined) {
                throw new RequiredError('environmentId', 'Required parameter requestParameters.environmentId was null or undefined when calling disableGlobalWalletAccessControl.');
            }
            const queryParameters = {};
            const headerParameters = {};
            const response = yield this.request({
                path: `/environments/{environmentId}/globalWallet/accessControl/disable`.replace(`{${"environmentId"}}`, encodeURIComponent(String(requestParameters.environmentId))),
                method: 'PUT',
                headers: headerParameters,
                query: queryParameters,
            }, initOverrides);
            return new JSONApiResponse(response, (jsonValue) => GlobalWalletAccessControlResponseFromJSON(jsonValue));
        });
    }
    /**
     * Disabled global wallet access control for this environment
     */
    disableGlobalWalletAccessControl(requestParameters, initOverrides) {
        return __awaiter(this, void 0, void 0, function* () {
            const response = yield this.disableGlobalWalletAccessControlRaw(requestParameters, initOverrides);
            return yield response.value();
        });
    }
    /**
     * Enable global wallet access control for this environment
     */
    enableGlobalWalletAccessControlRaw(requestParameters, initOverrides) {
        return __awaiter(this, void 0, void 0, function* () {
            if (requestParameters.environmentId === null || requestParameters.environmentId === undefined) {
                throw new RequiredError('environmentId', 'Required parameter requestParameters.environmentId was null or undefined when calling enableGlobalWalletAccessControl.');
            }
            const queryParameters = {};
            const headerParameters = {};
            const response = yield this.request({
                path: `/environments/{environmentId}/globalWallet/accessControl/enable`.replace(`{${"environmentId"}}`, encodeURIComponent(String(requestParameters.environmentId))),
                method: 'PUT',
                headers: headerParameters,
                query: queryParameters,
            }, initOverrides);
            return new JSONApiResponse(response, (jsonValue) => GlobalWalletAccessControlResponseFromJSON(jsonValue));
        });
    }
    /**
     * Enable global wallet access control for this environment
     */
    enableGlobalWalletAccessControl(requestParameters, initOverrides) {
        return __awaiter(this, void 0, void 0, function* () {
            const response = yield this.enableGlobalWalletAccessControlRaw(requestParameters, initOverrides);
            return yield response.value();
        });
    }
    /**
     * Get all the global wallet access control domains for a project environment
     */
    getGlobalWalletAccessControlListRaw(requestParameters, initOverrides) {
        return __awaiter(this, void 0, void 0, function* () {
            if (requestParameters.environmentId === null || requestParameters.environmentId === undefined) {
                throw new RequiredError('environmentId', 'Required parameter requestParameters.environmentId was null or undefined when calling getGlobalWalletAccessControlList.');
            }
            const queryParameters = {};
            const headerParameters = {};
            if (this.configuration && this.configuration.accessToken) {
                const token = this.configuration.accessToken;
                const tokenString = yield token("bearerAuth", []);
                if (tokenString) {
                    headerParameters["Authorization"] = `Bearer ${tokenString}`;
                }
            }
            const response = yield this.request({
                path: `/environments/{environmentId}/globalWallet/accessControl`.replace(`{${"environmentId"}}`, encodeURIComponent(String(requestParameters.environmentId))),
                method: 'GET',
                headers: headerParameters,
                query: queryParameters,
            }, initOverrides);
            return new JSONApiResponse(response, (jsonValue) => GlobalWalletAccessControlResponseFromJSON(jsonValue));
        });
    }
    /**
     * Get all the global wallet access control domains for a project environment
     */
    getGlobalWalletAccessControlList(requestParameters, initOverrides) {
        return __awaiter(this, void 0, void 0, function* () {
            const response = yield this.getGlobalWalletAccessControlListRaw(requestParameters, initOverrides);
            return yield response.value();
        });
    }
    /**
     * Updates a global wallet access control for this project environment
     */
    updateGlobalWalletAccessControlRaw(requestParameters, initOverrides) {
        return __awaiter(this, void 0, void 0, function* () {
            if (requestParameters.environmentId === null || requestParameters.environmentId === undefined) {
                throw new RequiredError('environmentId', 'Required parameter requestParameters.environmentId was null or undefined when calling updateGlobalWalletAccessControl.');
            }
            if (requestParameters.globalWalletAccessControlUpdateRequest === null || requestParameters.globalWalletAccessControlUpdateRequest === undefined) {
                throw new RequiredError('globalWalletAccessControlUpdateRequest', 'Required parameter requestParameters.globalWalletAccessControlUpdateRequest was null or undefined when calling updateGlobalWalletAccessControl.');
            }
            const queryParameters = {};
            const headerParameters = {};
            headerParameters['Content-Type'] = 'application/json';
            if (this.configuration && this.configuration.accessToken) {
                const token = this.configuration.accessToken;
                const tokenString = yield token("bearerAuth", []);
                if (tokenString) {
                    headerParameters["Authorization"] = `Bearer ${tokenString}`;
                }
            }
            const response = yield this.request({
                path: `/environments/{environmentId}/globalWallet/accessControl`.replace(`{${"environmentId"}}`, encodeURIComponent(String(requestParameters.environmentId))),
                method: 'PUT',
                headers: headerParameters,
                query: queryParameters,
                body: GlobalWalletAccessControlUpdateRequestToJSON(requestParameters.globalWalletAccessControlUpdateRequest),
            }, initOverrides);
            return new JSONApiResponse(response, (jsonValue) => GlobalWalletAccessControlResponseFromJSON(jsonValue));
        });
    }
    /**
     * Updates a global wallet access control for this project environment
     */
    updateGlobalWalletAccessControl(requestParameters, initOverrides) {
        return __awaiter(this, void 0, void 0, function* () {
            const response = yield this.updateGlobalWalletAccessControlRaw(requestParameters, initOverrides);
            return yield response.value();
        });
    }
}

export { GlobalWalletAccessControlApi };
