import { __awaiter } from '../../_virtual/_tslib.js';
import { BaseAPI, RequiredError, JSONApiResponse, VoidApiResponse } from '../runtime.js';
import '../models/AccessOutcomeEnum.js';
import '../models/ExchangeKeyEnum.js';
import '../models/AttestationConveyancePreference.js';
import '../models/AuthModeEnum.js';
import '../models/AuthStorageEnum.js';
import '../models/AuthenticatorAttachment.js';
import '../models/ResidentKeyRequirement.js';
import '../models/UserVerificationRequirement.js';
import '../models/AuthenticatorTransportProtocol.js';
import '../models/JwtVerifiedCredentialFormatEnum.js';
import '../models/ProviderEnum.js';
import '../models/WalletAddressType.js';
import '../models/EcdsaValidatorOptions.js';
import { EmbeddedWalletVersionEnumFromJSON } from '../models/EmbeddedWalletVersionEnum.js';
import '../models/HardwareWalletEnum.js';
import '../models/PasswordSourceTypeEnum.js';
import '../models/ProviderEntryPointVersionEnum.js';
import '../models/ProviderKernelVersionEnum.js';
import '../models/ThresholdSignatureScheme.js';
import '../models/WalletProviderEnum.js';
import '../models/MfaBackupCodeAcknowledgement.js';
import '../models/CustomFieldType.js';
import '../models/KycFieldType.js';
import '../models/BillingSubscriptionPlanTypeEnum.js';
import '../models/UnprocessableEntityErrorCode.js';
import '../models/ChainEnum.js';
import '../models/ChainalysisCheckResultEnum.js';
import '../models/MFADeviceType.js';
import { WalletFromJSON } from '../models/Wallet.js';
import '../models/EmbeddedWalletChainEnum.js';
import '../models/EmbeddedWalletProviderEnum.js';
import { CreateUserEmbeddedWalletsFromFarcasterRequestToJSON } from '../models/CreateUserEmbeddedWalletsFromFarcasterRequest.js';
import { CreateUserEmbeddedWalletsRequestToJSON } from '../models/CreateUserEmbeddedWalletsRequest.js';
import '../models/WaasChainEnum.js';
import { CreateWalletRequestToJSON } from '../models/CreateWalletRequest.js';
import '../models/CurrencyType.js';
import '../models/CustomHostnameStatusEnum.js';
import '../models/CustomHostnameUsageEnum.js';
import '../models/CustomHostnameVerificationType.js';
import '../models/DnsRecordType.js';
import '../models/TimeUnitEnum.js';
import '../models/EmbeddedWalletAuthType.js';
import '../models/EmbeddedWalletSecurityMethod.js';
import '../models/EnvironmentEnum.js';
import '../models/Network.js';
import '../models/ExternalWalletFundingTokenRule.js';
import '../models/OnrampProviders.js';
import '../models/SignInProviderEnum.js';
import '../models/SocialSignInProviderEnum.js';
import '../models/WaasBackupOptionsEnum.js';
import '../models/SdkViewSectionAlignment.js';
import '../models/SdkViewSectionType.js';
import '../models/SdkViewType.js';
import '../models/ZerodevBundlerProvider.js';
import '../models/ExportFormatEnum.js';
import '../models/ExportModelEnum.js';
import '../models/ExportStatusEnum.js';
import '../models/ExternalWalletFundingDefaultChain.js';
import '../models/GateRuleType.js';
import '../models/GlobalWalletAccessControlTypeEnum.js';
import '../models/HealthcheckStatus.js';
import '../models/InviteStatusEnum.js';
import '../models/RoleEnum.js';
import '../models/PublicKeyCredentialType.js';
import '../models/NextViewEnum.js';
import '../models/OauthResultStatus.js';
import '../models/WhenToImplementEnum.js';
import '../models/PublishEventsEvents.js';
import '../models/SubscriptionAdvancedScopeEnum.js';
import '../models/SubscriptionFreeScopeEnum.js';
import '../models/UserFieldsCheckEnum.js';
import '../models/UserFilterableFieldsEnum.js';
import '../models/UserIdentifierTypeEnum.js';
import { UserResponseFromJSON } from '../models/UserResponse.js';
import { UserWalletsResponseFromJSON } from '../models/UserWalletsResponse.js';
import '../models/VisitorFilterableFieldsEnum.js';

/* tslint:disable */
/**
 *
 */
class WalletsApi extends BaseAPI {
    /**
     * Creates a new embedded wallet for a user given an email or userId. If an email is provided and it is not associated with an existing user this call will also create a new user.
     * Creates a new embedded wallet for a user given an identifier
     */
    createEmbeddedWalletRaw(requestParameters, initOverrides) {
        return __awaiter(this, void 0, void 0, function* () {
            if (requestParameters.environmentId === null || requestParameters.environmentId === undefined) {
                throw new RequiredError('environmentId', 'Required parameter requestParameters.environmentId was null or undefined when calling createEmbeddedWallet.');
            }
            if (requestParameters.createUserEmbeddedWalletsRequest === null || requestParameters.createUserEmbeddedWalletsRequest === undefined) {
                throw new RequiredError('createUserEmbeddedWalletsRequest', 'Required parameter requestParameters.createUserEmbeddedWalletsRequest was null or undefined when calling createEmbeddedWallet.');
            }
            const queryParameters = {};
            const headerParameters = {};
            headerParameters['Content-Type'] = 'application/json';
            if (this.configuration && this.configuration.accessToken) {
                const token = this.configuration.accessToken;
                const tokenString = yield token("bearerAuth", []);
                if (tokenString) {
                    headerParameters["Authorization"] = `Bearer ${tokenString}`;
                }
            }
            const response = yield this.request({
                path: `/environments/{environmentId}/embeddedWallets`.replace(`{${"environmentId"}}`, encodeURIComponent(String(requestParameters.environmentId))),
                method: 'POST',
                headers: headerParameters,
                query: queryParameters,
                body: CreateUserEmbeddedWalletsRequestToJSON(requestParameters.createUserEmbeddedWalletsRequest),
            }, initOverrides);
            return new JSONApiResponse(response, (jsonValue) => UserResponseFromJSON(jsonValue));
        });
    }
    /**
     * Creates a new embedded wallet for a user given an email or userId. If an email is provided and it is not associated with an existing user this call will also create a new user.
     * Creates a new embedded wallet for a user given an identifier
     */
    createEmbeddedWallet(requestParameters, initOverrides) {
        return __awaiter(this, void 0, void 0, function* () {
            const response = yield this.createEmbeddedWalletRaw(requestParameters, initOverrides);
            return yield response.value();
        });
    }
    /**
     * Creates a new embedded wallet. This API is meant to be called from a frame server.
     * Creates a new embedded wallet. This API is meant to be called from a frame server.
     */
    createEmbeddedWalletFromFarcasterRaw(requestParameters, initOverrides) {
        return __awaiter(this, void 0, void 0, function* () {
            if (requestParameters.environmentId === null || requestParameters.environmentId === undefined) {
                throw new RequiredError('environmentId', 'Required parameter requestParameters.environmentId was null or undefined when calling createEmbeddedWalletFromFarcaster.');
            }
            if (requestParameters.createUserEmbeddedWalletsFromFarcasterRequest === null || requestParameters.createUserEmbeddedWalletsFromFarcasterRequest === undefined) {
                throw new RequiredError('createUserEmbeddedWalletsFromFarcasterRequest', 'Required parameter requestParameters.createUserEmbeddedWalletsFromFarcasterRequest was null or undefined when calling createEmbeddedWalletFromFarcaster.');
            }
            const queryParameters = {};
            const headerParameters = {};
            headerParameters['Content-Type'] = 'application/json';
            if (this.configuration && this.configuration.accessToken) {
                const token = this.configuration.accessToken;
                const tokenString = yield token("bearerAuth", []);
                if (tokenString) {
                    headerParameters["Authorization"] = `Bearer ${tokenString}`;
                }
            }
            const response = yield this.request({
                path: `/environments/{environmentId}/embeddedWallets/farcaster`.replace(`{${"environmentId"}}`, encodeURIComponent(String(requestParameters.environmentId))),
                method: 'POST',
                headers: headerParameters,
                query: queryParameters,
                body: CreateUserEmbeddedWalletsFromFarcasterRequestToJSON(requestParameters.createUserEmbeddedWalletsFromFarcasterRequest),
            }, initOverrides);
            return new JSONApiResponse(response, (jsonValue) => UserResponseFromJSON(jsonValue));
        });
    }
    /**
     * Creates a new embedded wallet. This API is meant to be called from a frame server.
     * Creates a new embedded wallet. This API is meant to be called from a frame server.
     */
    createEmbeddedWalletFromFarcaster(requestParameters, initOverrides) {
        return __awaiter(this, void 0, void 0, function* () {
            const response = yield this.createEmbeddedWalletFromFarcasterRaw(requestParameters, initOverrides);
            return yield response.value();
        });
    }
    /**
     * Creates a new wallet for the user. Note that this API is not meant for creating embedded wallets. To create embedded wallets use the /embeddedWallets endpoint.
     * Creates a new wallet for the user. Note that if the user already has an embedded wallet linked, this call will fail.
     */
    createWalletRaw(requestParameters, initOverrides) {
        return __awaiter(this, void 0, void 0, function* () {
            if (requestParameters.environmentId === null || requestParameters.environmentId === undefined) {
                throw new RequiredError('environmentId', 'Required parameter requestParameters.environmentId was null or undefined when calling createWallet.');
            }
            if (requestParameters.userId === null || requestParameters.userId === undefined) {
                throw new RequiredError('userId', 'Required parameter requestParameters.userId was null or undefined when calling createWallet.');
            }
            if (requestParameters.createWalletRequest === null || requestParameters.createWalletRequest === undefined) {
                throw new RequiredError('createWalletRequest', 'Required parameter requestParameters.createWalletRequest was null or undefined when calling createWallet.');
            }
            const queryParameters = {};
            const headerParameters = {};
            headerParameters['Content-Type'] = 'application/json';
            if (this.configuration && this.configuration.accessToken) {
                const token = this.configuration.accessToken;
                const tokenString = yield token("bearerAuth", []);
                if (tokenString) {
                    headerParameters["Authorization"] = `Bearer ${tokenString}`;
                }
            }
            const response = yield this.request({
                path: `/environments/{environmentId}/users/{userId}/wallets`.replace(`{${"environmentId"}}`, encodeURIComponent(String(requestParameters.environmentId))).replace(`{${"userId"}}`, encodeURIComponent(String(requestParameters.userId))),
                method: 'POST',
                headers: headerParameters,
                query: queryParameters,
                body: CreateWalletRequestToJSON(requestParameters.createWalletRequest),
            }, initOverrides);
            return new JSONApiResponse(response, (jsonValue) => WalletFromJSON(jsonValue));
        });
    }
    /**
     * Creates a new wallet for the user. Note that this API is not meant for creating embedded wallets. To create embedded wallets use the /embeddedWallets endpoint.
     * Creates a new wallet for the user. Note that if the user already has an embedded wallet linked, this call will fail.
     */
    createWallet(requestParameters, initOverrides) {
        return __awaiter(this, void 0, void 0, function* () {
            const response = yield this.createWalletRaw(requestParameters, initOverrides);
            return yield response.value();
        });
    }
    /**
     * Creates a new wallet for the user. Note that this API is not meant for creating embedded wallets. To create embedded wallets use the /embeddedWallets endpoint.
     * Creates a new wallet for the user (deprecated - use /environments/{environmentId}/users/{userId}/wallets instead)
     */
    createWalletLegacyRaw(requestParameters, initOverrides) {
        return __awaiter(this, void 0, void 0, function* () {
            if (requestParameters.userId === null || requestParameters.userId === undefined) {
                throw new RequiredError('userId', 'Required parameter requestParameters.userId was null or undefined when calling createWalletLegacy.');
            }
            if (requestParameters.createWalletRequest === null || requestParameters.createWalletRequest === undefined) {
                throw new RequiredError('createWalletRequest', 'Required parameter requestParameters.createWalletRequest was null or undefined when calling createWalletLegacy.');
            }
            const queryParameters = {};
            const headerParameters = {};
            headerParameters['Content-Type'] = 'application/json';
            if (this.configuration && this.configuration.accessToken) {
                const token = this.configuration.accessToken;
                const tokenString = yield token("bearerAuth", []);
                if (tokenString) {
                    headerParameters["Authorization"] = `Bearer ${tokenString}`;
                }
            }
            const response = yield this.request({
                path: `/users/{userId}/wallets`.replace(`{${"userId"}}`, encodeURIComponent(String(requestParameters.userId))),
                method: 'POST',
                headers: headerParameters,
                query: queryParameters,
                body: CreateWalletRequestToJSON(requestParameters.createWalletRequest),
            }, initOverrides);
            return new JSONApiResponse(response, (jsonValue) => WalletFromJSON(jsonValue));
        });
    }
    /**
     * Creates a new wallet for the user. Note that this API is not meant for creating embedded wallets. To create embedded wallets use the /embeddedWallets endpoint.
     * Creates a new wallet for the user (deprecated - use /environments/{environmentId}/users/{userId}/wallets instead)
     */
    createWalletLegacy(requestParameters, initOverrides) {
        return __awaiter(this, void 0, void 0, function* () {
            const response = yield this.createWalletLegacyRaw(requestParameters, initOverrides);
            return yield response.value();
        });
    }
    /**
     * Delete wallet
     */
    deleteWalletByIdRaw(requestParameters, initOverrides) {
        return __awaiter(this, void 0, void 0, function* () {
            if (requestParameters.environmentId === null || requestParameters.environmentId === undefined) {
                throw new RequiredError('environmentId', 'Required parameter requestParameters.environmentId was null or undefined when calling deleteWalletById.');
            }
            if (requestParameters.walletId === null || requestParameters.walletId === undefined) {
                throw new RequiredError('walletId', 'Required parameter requestParameters.walletId was null or undefined when calling deleteWalletById.');
            }
            const queryParameters = {};
            const headerParameters = {};
            if (this.configuration && this.configuration.accessToken) {
                const token = this.configuration.accessToken;
                const tokenString = yield token("bearerAuth", []);
                if (tokenString) {
                    headerParameters["Authorization"] = `Bearer ${tokenString}`;
                }
            }
            const response = yield this.request({
                path: `/environments/{environmentId}/wallets/{walletId}`.replace(`{${"environmentId"}}`, encodeURIComponent(String(requestParameters.environmentId))).replace(`{${"walletId"}}`, encodeURIComponent(String(requestParameters.walletId))),
                method: 'DELETE',
                headers: headerParameters,
                query: queryParameters,
            }, initOverrides);
            return new VoidApiResponse(response);
        });
    }
    /**
     * Delete wallet
     */
    deleteWalletById(requestParameters, initOverrides) {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.deleteWalletByIdRaw(requestParameters, initOverrides);
        });
    }
    /**
     * Delete wallet (deprecated - use /environments/{environmentId}/wallets/{walletId} instead)
     */
    deleteWalletByIdLegacyRaw(requestParameters, initOverrides) {
        return __awaiter(this, void 0, void 0, function* () {
            if (requestParameters.walletId === null || requestParameters.walletId === undefined) {
                throw new RequiredError('walletId', 'Required parameter requestParameters.walletId was null or undefined when calling deleteWalletByIdLegacy.');
            }
            const queryParameters = {};
            const headerParameters = {};
            if (this.configuration && this.configuration.accessToken) {
                const token = this.configuration.accessToken;
                const tokenString = yield token("bearerAuth", []);
                if (tokenString) {
                    headerParameters["Authorization"] = `Bearer ${tokenString}`;
                }
            }
            const response = yield this.request({
                path: `/wallets/{walletId}`.replace(`{${"walletId"}}`, encodeURIComponent(String(requestParameters.walletId))),
                method: 'DELETE',
                headers: headerParameters,
                query: queryParameters,
            }, initOverrides);
            return new VoidApiResponse(response);
        });
    }
    /**
     * Delete wallet (deprecated - use /environments/{environmentId}/wallets/{walletId} instead)
     */
    deleteWalletByIdLegacy(requestParameters, initOverrides) {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.deleteWalletByIdLegacyRaw(requestParameters, initOverrides);
        });
    }
    /**
     * Get the active embedded wallet versions for an environment
     */
    getActiveEmbeddedWalletVersionsForEnvironmentRaw(requestParameters, initOverrides) {
        return __awaiter(this, void 0, void 0, function* () {
            if (requestParameters.environmentId === null || requestParameters.environmentId === undefined) {
                throw new RequiredError('environmentId', 'Required parameter requestParameters.environmentId was null or undefined when calling getActiveEmbeddedWalletVersionsForEnvironment.');
            }
            const queryParameters = {};
            const headerParameters = {};
            if (this.configuration && this.configuration.accessToken) {
                const token = this.configuration.accessToken;
                const tokenString = yield token("bearerAuth", []);
                if (tokenString) {
                    headerParameters["Authorization"] = `Bearer ${tokenString}`;
                }
            }
            const response = yield this.request({
                path: `/environments/{environmentId}/embeddedWalletVersions`.replace(`{${"environmentId"}}`, encodeURIComponent(String(requestParameters.environmentId))),
                method: 'GET',
                headers: headerParameters,
                query: queryParameters,
            }, initOverrides);
            return new JSONApiResponse(response, (jsonValue) => jsonValue.map(EmbeddedWalletVersionEnumFromJSON));
        });
    }
    /**
     * Get the active embedded wallet versions for an environment
     */
    getActiveEmbeddedWalletVersionsForEnvironment(requestParameters, initOverrides) {
        return __awaiter(this, void 0, void 0, function* () {
            const response = yield this.getActiveEmbeddedWalletVersionsForEnvironmentRaw(requestParameters, initOverrides);
            return yield response.value();
        });
    }
    /**
     * Get a wallet using the ID
     */
    getWalletByIdRaw(requestParameters, initOverrides) {
        return __awaiter(this, void 0, void 0, function* () {
            if (requestParameters.environmentId === null || requestParameters.environmentId === undefined) {
                throw new RequiredError('environmentId', 'Required parameter requestParameters.environmentId was null or undefined when calling getWalletById.');
            }
            if (requestParameters.walletId === null || requestParameters.walletId === undefined) {
                throw new RequiredError('walletId', 'Required parameter requestParameters.walletId was null or undefined when calling getWalletById.');
            }
            const queryParameters = {};
            const headerParameters = {};
            if (this.configuration && this.configuration.accessToken) {
                const token = this.configuration.accessToken;
                const tokenString = yield token("bearerAuth", []);
                if (tokenString) {
                    headerParameters["Authorization"] = `Bearer ${tokenString}`;
                }
            }
            const response = yield this.request({
                path: `/environments/{environmentId}/wallets/{walletId}`.replace(`{${"environmentId"}}`, encodeURIComponent(String(requestParameters.environmentId))).replace(`{${"walletId"}}`, encodeURIComponent(String(requestParameters.walletId))),
                method: 'GET',
                headers: headerParameters,
                query: queryParameters,
            }, initOverrides);
            return new JSONApiResponse(response, (jsonValue) => WalletFromJSON(jsonValue));
        });
    }
    /**
     * Get a wallet using the ID
     */
    getWalletById(requestParameters, initOverrides) {
        return __awaiter(this, void 0, void 0, function* () {
            const response = yield this.getWalletByIdRaw(requestParameters, initOverrides);
            return yield response.value();
        });
    }
    /**
     * Get a wallet using the ID (deprecated - use /environments/{environmentId}/wallets/{walletId} instead)
     */
    getWalletByIdLegacyRaw(requestParameters, initOverrides) {
        return __awaiter(this, void 0, void 0, function* () {
            if (requestParameters.walletId === null || requestParameters.walletId === undefined) {
                throw new RequiredError('walletId', 'Required parameter requestParameters.walletId was null or undefined when calling getWalletByIdLegacy.');
            }
            const queryParameters = {};
            const headerParameters = {};
            if (this.configuration && this.configuration.accessToken) {
                const token = this.configuration.accessToken;
                const tokenString = yield token("bearerAuth", []);
                if (tokenString) {
                    headerParameters["Authorization"] = `Bearer ${tokenString}`;
                }
            }
            const response = yield this.request({
                path: `/wallets/{walletId}`.replace(`{${"walletId"}}`, encodeURIComponent(String(requestParameters.walletId))),
                method: 'GET',
                headers: headerParameters,
                query: queryParameters,
            }, initOverrides);
            return new JSONApiResponse(response, (jsonValue) => WalletFromJSON(jsonValue));
        });
    }
    /**
     * Get a wallet using the ID (deprecated - use /environments/{environmentId}/wallets/{walletId} instead)
     */
    getWalletByIdLegacy(requestParameters, initOverrides) {
        return __awaiter(this, void 0, void 0, function* () {
            const response = yield this.getWalletByIdLegacyRaw(requestParameters, initOverrides);
            return yield response.value();
        });
    }
    /**
     * Get wallets by user
     */
    getWalletsByUserIdRaw(requestParameters, initOverrides) {
        return __awaiter(this, void 0, void 0, function* () {
            if (requestParameters.environmentId === null || requestParameters.environmentId === undefined) {
                throw new RequiredError('environmentId', 'Required parameter requestParameters.environmentId was null or undefined when calling getWalletsByUserId.');
            }
            if (requestParameters.userId === null || requestParameters.userId === undefined) {
                throw new RequiredError('userId', 'Required parameter requestParameters.userId was null or undefined when calling getWalletsByUserId.');
            }
            const queryParameters = {};
            const headerParameters = {};
            if (this.configuration && this.configuration.accessToken) {
                const token = this.configuration.accessToken;
                const tokenString = yield token("bearerAuth", []);
                if (tokenString) {
                    headerParameters["Authorization"] = `Bearer ${tokenString}`;
                }
            }
            const response = yield this.request({
                path: `/environments/{environmentId}/users/{userId}/wallets`.replace(`{${"environmentId"}}`, encodeURIComponent(String(requestParameters.environmentId))).replace(`{${"userId"}}`, encodeURIComponent(String(requestParameters.userId))),
                method: 'GET',
                headers: headerParameters,
                query: queryParameters,
            }, initOverrides);
            return new JSONApiResponse(response, (jsonValue) => UserWalletsResponseFromJSON(jsonValue));
        });
    }
    /**
     * Get wallets by user
     */
    getWalletsByUserId(requestParameters, initOverrides) {
        return __awaiter(this, void 0, void 0, function* () {
            const response = yield this.getWalletsByUserIdRaw(requestParameters, initOverrides);
            return yield response.value();
        });
    }
    /**
     * Get wallets by user (deprecated - use /environments/{environmentId}/users/{userId}/wallets instead)
     */
    getWalletsByUserIdLegacyRaw(requestParameters, initOverrides) {
        return __awaiter(this, void 0, void 0, function* () {
            if (requestParameters.userId === null || requestParameters.userId === undefined) {
                throw new RequiredError('userId', 'Required parameter requestParameters.userId was null or undefined when calling getWalletsByUserIdLegacy.');
            }
            const queryParameters = {};
            const headerParameters = {};
            if (this.configuration && this.configuration.accessToken) {
                const token = this.configuration.accessToken;
                const tokenString = yield token("bearerAuth", []);
                if (tokenString) {
                    headerParameters["Authorization"] = `Bearer ${tokenString}`;
                }
            }
            const response = yield this.request({
                path: `/users/{userId}/wallets`.replace(`{${"userId"}}`, encodeURIComponent(String(requestParameters.userId))),
                method: 'GET',
                headers: headerParameters,
                query: queryParameters,
            }, initOverrides);
            return new JSONApiResponse(response, (jsonValue) => UserWalletsResponseFromJSON(jsonValue));
        });
    }
    /**
     * Get wallets by user (deprecated - use /environments/{environmentId}/users/{userId}/wallets instead)
     */
    getWalletsByUserIdLegacy(requestParameters, initOverrides) {
        return __awaiter(this, void 0, void 0, function* () {
            const response = yield this.getWalletsByUserIdLegacyRaw(requestParameters, initOverrides);
            return yield response.value();
        });
    }
}

export { WalletsApi };
